$code = @'
Imports System
Imports System.Configuration.Install
Imports System.Collections.Generic
Imports System.Text
Imports System.ComponentModel
Imports System.Management.Automation

Namespace MSPressBuch.PowerShell.Cmdlets
  <RunInstaller(True)> Public Class ClipboardSnapin
    Inherits PSSnapIn

    Public Sub New()
      MyBase.New()
    End Sub

    Public Overrides ReadOnly Property Name() As String
      Get
        Return "Clipboard-Erweiterung"
      End Get
    End Property

    Public Overrides ReadOnly Property Vendor() As String
      Get
        Return "Dr. Tobias Weltner"
      End Get
    End Property

    Public Overrides ReadOnly Property VendorResource() As String
      Get
        Return String.Format("{0},{1}", Name, Vendor)
      End Get
    End Property

    Public Overrides ReadOnly Property Description() As String
      Get
        Return "copy text to clipboard"
      End Get
    End Property

    Public Overrides ReadOnly Property DescriptionResource() As String
      Get
        Return String.Format("{0},{1}", Name, Description)
      End Get
    End Property
  End Class

  <Cmdlet(VerbsData.Out, "ClipboardText")> Public Class ClipboardHelper
    Inherits Cmdlet

    Private data As String = ""
    Private _Text() As String
    Private linefeed as string = ""

    <Parameter(Mandatory:=False, Position:=0, ValueFromPipeline:=True, _
       HelpMessage:="Text to copy to Clipboard"), ValidateNotNullOrEmpty()> _
       Public Property Text() As String()
         Get
           Return _Text
         End Get
         Set(ByVal value As String())
           _Text = value
         End Set
       End Property

    Protected Overrides Sub BeginProcessing()
      WriteDebug("Enter BeginProcessing")
      data = ""
      MyBase.BeginProcessing()
    End Sub
    Protected Overrides Sub EndProcessing()
      WriteDebug("Enter EndProcessing")
      Utility.CopyToClipboard(data)
      MyBase.EndProcessing()
    End Sub
    Protected Overrides Sub ProcessRecord()
      WriteDebug("Processing Record")
      Try
        For Each Line As String In _Text
          data += Line
          data += linefeed
          linefeed = (chr(13) + chr(10))
        Next
      Catch ex as Exception
        WriteDebug("Failure: " & ex.Message)
      End Try
      WriteDebug("Done Processing Record")
    End Sub
  End Class

  Public Class Utility
    Private Declare Function OpenClipboard Lib "user32" (ByVal hwnd As Integer) As Integer
    Private Declare Function EmptyClipboard Lib "user32" () As Integer
    Private Declare Function CloseClipboard Lib "user32" () As Integer
    Private Declare Function SetClipboardData Lib "user32" (ByVal wFormat As Integer, ByVal hMem As Integer) As Integer
    Private Declare Function GlobalAlloc Lib "kernel32" (ByVal wFlags As Integer, ByVal dwBytes As Integer) As Integer
    Private Declare Function GlobalLock Lib "kernel32" (ByVal hMem As Integer) As Integer
    Private Declare Function GlobalUnlock Lib "kernel32" (ByVal hMem As Integer) As Integer
    Private Declare Function lstrcpy Lib "kernel32" (ByVal lpString1 As Integer, ByVal lpString2 As String) As Integer

    Public Shared Sub CopyToClipboard(ByVal text As String)
      Dim result As Boolean = False
      Dim mem As Integer = GlobalAlloc(&H42, text.Length + 1)
      Dim lockedmem As Integer = GlobalLock(mem)
      lstrcpy(lockedmem, text)
      If GlobalUnlock(mem) = 0 Then
        If OpenClipboard(0) Then
          EmptyClipboard()
          result = SetClipboardData(1, mem)
          CloseClipboard()
        End If
      End If
    End Sub
  End Class
End Namespace
'@

$code | out-file cmdlet.vb
$path = resolve-path cmdlet.vb
$compiler = "$env:windir/Microsoft.NET/Framework/v2.0.50727/vbc"
$ref = [PsObject].Assembly.Location
&$compiler /target:library /reference:$ref $path
dir cmdlet.dll
$path = resolve-path cmdlet.dll
$register = "$env:windir/Microsoft.NET/Framework/v2.0.50727/installutil"
&$register $path
Add-PSSnapin Clipboard-Erweiterung
Out-ClipboardText -text "Halli Hallo"
